export interface UnitOfWork {
    beginWork(): void;
    commitWork(): Promise<void>;
}
export interface UowObject<Tx> {
    createByTx(tx: Tx): Promise<void>;
    updateByTx(tx: Tx): Promise<void>;
    deleteByTx(tx: Tx): Promise<void>;
}
export declare abstract class Uow<Tx> implements UnitOfWork {
    private creates;
    private updates;
    private deletes;
    private isActive;
    /**
     * begin begins a new transaction
     */
    protected abstract begin(): Promise<Tx>;
    /**
     * commit commits a transaction
     */
    protected abstract commit(tx: Tx): Promise<void>;
    /**
     * rollback rollbacks a transaction
     */
    protected abstract rollback(tx: Tx): Promise<void>;
    /**
     * release releases a transaction (should be overridden if needed)
     */
    protected release(tx: Tx): Promise<void>;
    /**
     * beginWork begins a transaction in this unit of work
     */
    beginWork(): void;
    /**
     * commitWork commits all actions in this unit of work
     */
    commitWork(): Promise<void>;
    /**
     * markCreate caches object which is going to be created
     */
    protected markCreate(uowObj: UowObject<Tx>): Promise<void>;
    /**
     * markUpdate caches object which is going to be updated
     */
    protected markUpdate(uowObj: UowObject<Tx>): Promise<void>;
    /**
     * markDelete caches object which is going to be deleted
     */
    protected markDelete(uowObj: UowObject<Tx>): Promise<void>;
    private mark;
    private commitChanges;
    private commitCreates;
    private commitUpdates;
    private commitDeletes;
    private dispose;
}
